@@ -11,6 +11,7 @@ import io
 from typing import List, IO, Union, AnyStr
 from copy import deepcopy
 from collections import defaultdict
+from PIL import Image
 
 from trp.trp2 import TDocument, TDocumentSchema
 
@@ -21,6 +22,7 @@ from textractor.entities.line import Line
 from textractor.entities.page import Page
 from textractor.entities.table import Table
 from textractor.entities.query import Query
+from textractor.entities.signature import Signature
 from textractor.exceptions import InputError
 from textractor.entities.key_value import KeyValue
 from textractor.entities.bbox import SpatialObject
@@ -182,6 +184,16 @@ class Document(SpatialObject):
         """
         return EntityList(sum([page.queries for page in self.pages], []))
 
+    @property
+    def signatures(self) -> List[Signature]:
+        """
+        Returns all the :class:`Signature` objects present in the Document.
+
+        :return: List of Signature objects.
+        :rtype: EntityList[Signature]
+        """
+        return EntityList(sum([page.signatures for page in self.pages], []))
+
     @property
     def identity_document(self) -> EntityList[IdentityDocument]:
         """
@@ -202,6 +214,16 @@ class Document(SpatialObject):
         """
         self._identity_document = identity_documents
 
+    @property
+    def images(self) -> List[Image.Image]:
+        """
+        Returns all the page images in the Document.
+
+        :return: List of PIL Image objects.
+        :rtype: PIL.Image
+        """
+        return [page.image for page in self._pages]
+
     @property
     def pages(self) -> List[Page]:
         """
@@ -251,6 +273,8 @@ class Document(SpatialObject):
                 f"Key-values - {len(self.key_values)}",
                 f"Checkboxes - {len(self.checkboxes)}",
                 f"Tables - {len(self.tables)}",
+                f"Queries - {len(self.queries)}",
+                f"Signatures - {len(self.signatures)}",
                 f"Identity Documents - {len(self.identity_documents)}",
                 f"Expense Documents - {len(self.expense_documents)}",
             ]
